Operational Transformation (OT)
This module provides operational transformation for concurrent text editing. OT allows multiple users to edit the same document concurrently while maintaining consistency.
Re-exports
pub use composer::OperationComposer;pub use text_operation::Operation;pub use text_operation::TextOperation;
Modules
- composer
- Operation composition utilities
- text_
operation - Text operations for operational transformation
Traits
- Transform
- Trait for transformable operations