Transform

Trait Transform 

pub trait Transform:
    Clone
    + Serialize
    + for<'de> Deserialize<'de> {
    // Required methods
    fn transform(&self, other: &Self) -> SyncResult<Self>;
    fn compose(&self, other: &Self) -> SyncResult<Self>;
    fn invert(&self) -> SyncResult<Self>;
}
Trait for transformable operations

Required Methods

fn transform(&self, other: &Self) -> SyncResult<Self>

Transforms this operation against another concurrent operation

Returns the transformed version of this operation that can be applied after the other operation.

Arguments
  • other - The concurrent operation to transform against
Returns

The transformed operation

fn compose(&self, other: &Self) -> SyncResult<Self>

Composes this operation with another sequential operation

Returns a single operation that has the same effect as applying this operation followed by the other operation.

Arguments
  • other - The operation to compose with
Returns

The composed operation

fn invert(&self) -> SyncResult<Self>

Inverts this operation

Returns an operation that undoes the effect of this operation.

Returns

The inverted operation

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors